"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSQLSentence = isSQLSentence;
exports.detectSQLInjection = detectSQLInjection;
const reservedWords = [
    'SELECT',
    'UPDATE',
    'DELETE',
    'INSERT',
    'DROP',
    'UNION',
    'AND',
    'OR',
    'WHERE',
    'FROM',
    'JOIN',
    'TABLE',
    'INTO',
    'VALUES',
    'SET',
    'CREATE',
    'ALTER',
    'INDEX',
    'VIEW',
    'TRIGGER',
    'PROCEDURE',
    'FUNCTION',
    'DATABASE',
    'COLUMN',
    'KEY',
    'PRIMARY',
    'FOREIGN',
    'REFERENCES',
    'GROUP',
    'ORDER',
    'BY',
    'HAVING',
    'LIMIT',
    'OFFSET',
];
function isSQLSentence(input) {
    const upperInput = input.toUpperCase().trim();
    // Detectar si contiene más de una palabra reservada
    const words = upperInput.split(/\s+/);
    const reservedWordCount = words.filter((word) => reservedWords.includes(word)).length;
    if (reservedWordCount > 1) {
        return true; // Es una sentencia SQL si contiene más de una palabra reservada
    }
    // Detectar patrones comunes de sentencias SQL
    const sqlPatterns = [
        /\bSELECT\b.*\bFROM\b/,
        /\bINSERT\b.*\bINTO\b/,
        /\bUPDATE\b.*\bSET\b/,
        /\bDELETE\b.*\bFROM\b/,
        /\bCREATE\b.*\bTABLE\b/,
        /\bDROP\b.*\bTABLE\b/,
        /\bALTER\b.*\bTABLE\b/,
        /\bUNION\b.*\bSELECT\b/,
        /\bJOIN\b.*\bON\b/,
        /\bCREATE\b.*\bDATABASE\b/,
        /\bCREATE\b.*\bVIEW\b/,
        /\bCREATE\b.*\bINDEX\b/,
        /\bCREATE\b.*\bTRIGGER\b/,
        /\bCREATE\b.*\bPROCEDURE\b/,
        /\bCREATE\b.*\bFUNCTION\b/,
        /\bALTER\b.*\bDATABASE\b/,
        /\bALTER\b.*\bVIEW\b/,
        /\bALTER\b.*\bINDEX\b/,
        /\bALTER\b.*\bTRIGGER\b/,
        /\bALTER\b.*\bPROCEDURE\b/,
        /\bALTER\b.*\bFUNCTION\b/,
        /\bDROP\b.*\bDATABASE\b/,
        /\bDROP\b.*\bVIEW\b/,
        /\bDROP\b.*\bINDEX\b/,
        /\bDROP\b.*\bTRIGGER\b/,
        /\bDROP\b.*\bPROCEDURE\b/,
        /\bDROP\b.*\bFUNCTION\b/,
    ];
    for (const pattern of sqlPatterns) {
        if (pattern.test(upperInput)) {
            return true; // Es una sentencia SQL si coincide con algún patrón
        }
    }
    return false; // No es una sentencia SQL si no cumple con los criterios anteriores
}
function detectSQLInjection(input) {
    const sqlInjectionPattern = /(\b(SELECT|UPDATE|DELETE|INSERT|DROP|UNION|AND|OR|--)|\b\d{2,}\b|(['"];\s*--))/i;
    return sqlInjectionPattern.test(input);
}
//# sourceMappingURL=sqlInjectionDetector.js.map