"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanFormData = scanFormData;
const sqlInjectionDetector_1 = require("../detectors/sqlInjectionDetector");
const xssDetector_1 = require("../detectors/xssDetector");
const scriptInjectionDetector_1 = require("../detectors/scriptInjectionDetector");
function scanFormData(formData, options) {
    const issues = [];
    const { keys, values, detectSentences, detectReservedWords } = options;
    formData.forEach((value, key) => {
        const valueString = value.toString();
        if (keys) {
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(key)) {
                issues.push(`SQL Sentence detected in form data key ${key}`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(key)) {
                issues.push(`SQL Injection detected in form data key ${key}`);
            }
            if ((0, xssDetector_1.detectXSS)(key)) {
                issues.push(`XSS detected in form data key ${key}`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(key)) {
                issues.push(`Script Injection detected in form data key ${key}`);
            }
        }
        if (values) {
            if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(valueString)) {
                issues.push(`SQL Sentence detected in form data value ${key}`);
            }
            if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(valueString)) {
                issues.push(`SQL Injection detected in form data value ${key}`);
            }
            if ((0, xssDetector_1.detectXSS)(valueString)) {
                issues.push(`XSS detected in form data value ${key}`);
            }
            if ((0, scriptInjectionDetector_1.detectScriptInjection)(valueString)) {
                issues.push(`Script Injection detected in form data value ${key}`);
            }
        }
    });
    return issues;
}
//# sourceMappingURL=scanFormData.js.map