import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { detectScriptInjection } from '../detectors/scriptInjectionDetector';

interface ScanOptions {
  keys: boolean;
  values: boolean;
  detectSentences: boolean;
  detectReservedWords: boolean;
}

export function scanBody(body: any, options: ScanOptions): string[] {
  const issues: string[] = [];

  const { keys, values, detectSentences, detectReservedWords } = options;

  if (keys) {
    for (const key of Object.keys(body)) {
      if (detectSentences && isSQLSentence(key)) {
        issues.push(`SQL Sentence detected in body key ${key}`);
      }
      if (detectReservedWords && detectSQLInjection(key)) {
        issues.push(`SQL Injection detected in body key ${key}`);
      }
      if (detectXSS(key)) {
        issues.push(`XSS detected in body key ${key}`);
      }
      if (detectScriptInjection(key)) {
        issues.push(`Script Injection detected in body key ${key}`);
      }
    }
  }

  if (values) {
    const bodyString = JSON.stringify(body);
    if (detectSentences && isSQLSentence(bodyString)) {
      issues.push('SQL Sentence detected in body');
    }
    if (detectReservedWords && detectSQLInjection(bodyString)) {
      issues.push('SQL Injection detected in body');
    }
    if (detectXSS(bodyString)) {
      issues.push('XSS detected in body');
    }
    if (detectScriptInjection(bodyString)) {
      issues.push('Script Injection detected in body');
    }
  }

  return issues;
}
