import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { detectScriptInjection } from '../detectors/scriptInjectionDetector';

interface ScanOptions {
  keys: boolean;
  values: boolean;
  detectSentences: boolean;
  detectReservedWords: boolean;
}

export function scanFormData(
  formData: FormData,
  options: ScanOptions,
): string[] {
  const issues: string[] = [];

  const { keys, values, detectSentences, detectReservedWords } = options;

  formData.forEach((value, key) => {
    const valueString = value.toString();
    if (keys) {
      if (detectSentences && isSQLSentence(key)) {
        issues.push(`SQL Sentence detected in form data key ${key}`);
      }
      if (detectReservedWords && detectSQLInjection(key)) {
        issues.push(`SQL Injection detected in form data key ${key}`);
      }
      if (detectXSS(key)) {
        issues.push(`XSS detected in form data key ${key}`);
      }
      if (detectScriptInjection(key)) {
        issues.push(`Script Injection detected in form data key ${key}`);
      }
    }
    if (values) {
      if (detectSentences && isSQLSentence(valueString)) {
        issues.push(`SQL Sentence detected in form data value ${key}`);
      }
      if (detectReservedWords && detectSQLInjection(valueString)) {
        issues.push(`SQL Injection detected in form data value ${key}`);
      }
      if (detectXSS(valueString)) {
        issues.push(`XSS detected in form data value ${key}`);
      }
      if (detectScriptInjection(valueString)) {
        issues.push(`Script Injection detected in form data value ${key}`);
      }
    }
  });

  return issues;
}
