import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { detectScriptInjection } from '../detectors/scriptInjectionDetector';

interface ScanOptions {
  detectSentences: boolean;
  detectReservedWords: boolean;
}

export function scanUrl(url: string, options: ScanOptions): string[] {
  const issues: string[] = [];

  if (options.detectSentences && isSQLSentence(url)) {
    issues.push('SQL Sentence detected in URL');
  }
  if (options.detectReservedWords && detectSQLInjection(url)) {
    issues.push('SQL Injection detected in URL');
  }
  if (detectXSS(url)) {
    issues.push('XSS detected in URL');
  }
  if (detectScriptInjection(url)) {
    issues.push('Script Injection detected in URL');
  }

  return issues;
}
